Summary:        C library to handle the Public Suffix List
Name:           libpsl
Version:        0.21.2
Release:        5%{?dist}
License:        MIT
URL:            https://github.com/rockdaboot/libpsl
Source0:        https://github.com/rockdaboot/libpsl/releases/download/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  gcc make glib2-devel python3-devel
BuildRequires:  gettext-devel libicu-devel libidn2-devel libunistring-devel libxslt publicsuffix-list

Requires:       publicsuffix-list-dafsa

%description
A Public Suffix List is a collection of Top Level Domains (TLDs) suffixes. 
TLDs include Global Top Level Domains (gTLDs) like .com and .net; Country 
Top Level Domains (ccTLDs) like .de and .cn; and Brand Top Level Domains 
like .apple and .google. Brand TLDs allows users to register their own top 
level domain that exist at the same level as ICANN's gTLDs. Brand TLDs are 
sometimes referred to as Vanity Domains.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       publicsuffix-list

%description    devel
This package contains libraries and header files for
developing applications that use %{name}.

%package -n     psl
Summary:        Commandline utility to explore the Public Suffix List

%description -n psl
This package contains a commandline utility to explore the Public Suffix List,
for example it checks if domains are public suffixes, checks if cookie-domain
is acceptable for domains and so on.

%package -n     psl-make-dafsa
Summary:        generate a compact and optimized DAFSA from a Public Suffix List

%description -n psl-make-dafsa
psl-make-dafsa produces C/C++ code or an architecture-independent binary object 
that represents a Deterministic Acyclic Finite State Automaton (DAFSA) from a 
textual representation of a Public Suffix List.  Input and output files must be 
specified on the command line.

This compact representation enables optimized queries of the list, saving both 
time and space when compared to searches of human-readable representations.

%prep
%autosetup -n %{name}-%{version}
rm -frv list
ln -sv %{_datadir}/publicsuffix list
sed -i -e "1s|#!.*|#!%{__python3}|" src/psl-make-dafsa

%build
%configure --disable-silent-rules \
           --disable-static       \
           --enable-man           \
           --disable-gtk-doc      \
           --enable-builtin=libicu \
           --enable-runtime=libidn2 \
           --with-psl-distfile=%{_datadir}/publicsuffix/public_suffix_list.dafsa  \
           --with-psl-file=%{_datadir}/publicsuffix/effective_tld_names.dat       \
           --with-psl-testfile=%{_datadir}/publicsuffix/test_psl.txt
sed -i libtool \
    -e 's|^\(runpath_var=\).*$|\1|' \
    -e 's|^\(hardcode_libdir_flag_spec=\).*$|\1|'
%make_build

%install
%make_install
install -m0755 src/psl-make-dafsa %{buildroot}%{_bindir}/
find %{buildroot} -name '*.la' -delete -print

%check
export LD_LIBRARY_PATH=%{_builddir}/%{name}-%{version}/src/.libs
make check

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license COPYING
%{_libdir}/libpsl.so.5
%{_libdir}/libpsl.so.5.*

%files devel
%doc AUTHORS NEWS
%{_datadir}/gtk-doc/html/libpsl/
%{_includedir}/libpsl.h
%{_libdir}/libpsl.so
%{_libdir}/pkgconfig/libpsl.pc

%files -n psl
%doc AUTHORS NEWS
%license COPYING
%{_bindir}/psl
%{_mandir}/man1/psl.1*

%files -n psl-make-dafsa
%license COPYING
%{_bindir}/psl-make-dafsa
%{_mandir}/man1/psl-make-dafsa.1*

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.21.2-5
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.21.2-4
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.21.2-3
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 23 2023 rockerzhu <rockerzhu@tencent.com> - 0.21.2-2
- Rebuilt for icu 73.2

* Thu Aug 17 2023 Shuo Wang <abushwang@tencent.com> - 0.21.2-1
- update to 0.21.2

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.21.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.21.1-2
- Rebuilt for OpenCloudOS Stream 23

* Tue Jul 12 2022 jackbertluo <jackbertluo@tencent.com> - 0.21.1-1
- Initial build
